Crate eure_json

Crate eure_json 

eure-json

JSON conversion support for Eure.

This crate is still under development and published for name reservation purpose.

Part of the Eure project - a minimalist, schema-friendly format with an algebraic data model that’s compatible with JSON.

Structs

Config
EureToJson
EureToJsonFormatted
JsonToEure

Enums

EureToJsonError
JsonToEureError
Errors that can occur when converting JSON to Eure. Currently this is infallible, but the error type is provided for future extensibility and API consistency.

Functions

document_to_value
eure_to_json
eure_to_json_formatted
Convert a Eure file to JSON with formatted error reporting.
json_to_eure
Convert a JSON file to an Eure document.
value_to_document
Convert a JSON value to an EureDocument.